@@ -1,14 +1,14 @@
 from _warnings import warn
 from datetime import datetime
 
-import requests
+import api_request
 
 
 class User:
     def __init__(self, user_id: int):
         if type(user_id) is not int:
             raise TypeError(f'must be int, not {type(user_id).__name__}')
-        response = profile_v2_request(user_id)
+        response = api_request.profile_v2_request(user_id)
         if response['code'] == 1:
             raise ValueError('no user found')
         user_info: dict = response['body']['user_info']
@@ -36,6 +36,7 @@ class User:
         self.viewers = user_info.get('viewers')
         self.gift_revenue = user_info.get('gift_revenue_history')
         self.latest_live_title = user_info.get('anchor_intro')
+        self.latest_live_thumbnail = user_info.get('pic')
         self.birth = user_info.get('birth')
 
     def fetch_playback(self, limit: int = 30, index: int = None):
@@ -48,13 +49,13 @@ class User:
             if limit != 30:
                 warn('The "limit" argument was ignored because the "index" argument has been passed.')
             limit = 1
-            response = playback_request(user_id, limit, index+1)
+            response = api_request.playback_request(user_id, limit, index + 1)
             if response['code'] == 1:
                 raise ValueError('no user found')
             playback = PlayBack(response['body'][0], user_id, self)
             return playback
         else:
-            response = playback_request(user_id, limit)
+            response = api_request.playback_request(user_id, limit)
             if response['code'] == 1:
                 raise ValueError('no user found')
             body = response['body']
@@ -81,26 +82,9 @@ class PlayBack:
 def is_live(user_id: int) -> bool:
     if type(user_id) is not int:
         raise TypeError(f'must be int, not {type(user_id).__name__}')
-    response = profile_v2_request(user_id)
+    response = api_request.profile_v2_request(user_id)
     anchor_live = response['body']['user_info']['anchor_live']
     if anchor_live == 11:
         return True
     else:
         return False
-
-
-def profile_v2_request(user_id: int) -> dict:
-    url = f"https://cloudac.mildom.com/nonolive/gappserv/user/profileV2?user_id={user_id}&__platform=web"
-    response = requests.get(url).json()
-    return response
-
-
-def playback_request(user_id: int, limit, page=None) -> dict:
-    if page is not None:
-        url = f"https://cloudac.mildom.com/nonolive/videocontent/profile/playbackList" \
-              f"?__platform=web&user_id={user_id}&limit={limit}&page={page}"
-    else:
-        url = f"https://cloudac.mildom.com/nonolive/videocontent/profile/playbackList" \
-              f"?__platform=web&user_id={user_id}&limit={limit}"
-    response = requests.get(url).json()
-    return response
